package Perl::Examples::POD::Link;

1;
# ABSTRACT: Show the various examples of links

__END__

=pod

=encoding UTF-8

=head1 NAME

Perl::Examples::POD::Link - Show the various examples of links

=head1 VERSION

This document describes version 0.06 of Perl::Examples::POD::Link (from Perl distribution Perl-Examples), released on 2016-03-21.

=head1 DESCRIPTION

=head2 Links to POD

Link to module: L<Perl::Examples>

Link to module + section: L<Perl::Examples/"DESCRIPTION">

Link this page + section: L</"URL links">

Link to module with text: L<The Perl-Examples main module|Perl::Examples>

Link to module with text + section: L<The description of Perl-Examples main module|Perl::Examples/"DESCRIPTION">

Link this page with text + section: L<A collection of URL links|/"URL links">

Link to script: L<perl-example-die>

=head2 URL links

URL without text: L<http://www.example.com/page.html>

URL with text: L<An example page|http://www.example.com/page.html>

http scheme with port: L<http://www.example.com:8001/>

https scheme: L<https://www.example.com/>

ftp scheme: L<ftp://ftp.example.com/>

mailto scheme: L<mailto:example@example.com>

Some custom scheme: L<foo://bar>

=head2 POD link in head2: L<Perl::Examples>

=head2 URL link in head2: L<http://www.example.com/head2.html>

=head2 Links in bullet points

=over

=item * L<Perl::Examples>

=item * L<http://www.example.com/bullet.html>

=back

=head2 Not links

 L<link in verbatim is not link|Perl::Example>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perl-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perl-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
